@@ -11,7 +11,6 @@ from .base import (
     RelatedBase,
     RelatedEntityBase,
     MimetypeLinkBase,
-    IdentifierBase,
 )
 from .people_orgs import Organization
 from .jurisdiction import LegislativeSession
@@ -59,7 +58,6 @@ class BillAbstract(RelatedBase):
     bill = models.ForeignKey(Bill, related_name="abstracts", on_delete=models.CASCADE)
     abstract = models.TextField()
     note = models.TextField(blank=True)
-    date = models.TextField(max_length=10, blank=True)  # YYYY[-MM[-DD]]
 
     def __str__(self):
         return "{0} abstract".format(self.bill.identifier)
@@ -82,11 +80,14 @@ class BillTitle(RelatedBase):
         db_table = "opencivicdata_billtitle"
 
 
-class BillIdentifier(IdentifierBase):
+class BillIdentifier(RelatedBase):
     bill = models.ForeignKey(
         Bill, related_name="other_identifiers", on_delete=models.CASCADE
     )
-    note = models.TextField(blank=True)
+    identifier = models.CharField(
+        max_length=300,
+        help_text="A unique identifier developed by an upstream or third party source.",
+    )
 
     class Meta:
         db_table = "opencivicdata_billidentifier"
@@ -106,7 +107,6 @@ class BillAction(RelatedBase):
         base_field=models.TextField(), blank=True, default=list
     )  # enum
     order = models.PositiveIntegerField()
-    extras = JSONField(default=dict, blank=True)
 
     class Meta:
         db_table = "opencivicdata_billaction"
