@@ -19,11 +19,6 @@ class Organization(OCDBase):
 
     id = OCDIDField(ocd_type="organization")
     name = models.CharField(max_length=300, help_text="The name of the Organization.")
-    image = models.URLField(
-        blank=True,
-        max_length=2000,
-        help_text="A URL leading to an image that identifies the Organization visually.",
-    )
     parent = models.ForeignKey(
         "self",
         related_name="children",
@@ -46,16 +41,6 @@ class Organization(OCDBase):
         choices=common.ORGANIZATION_CLASSIFICATION_CHOICES,
         help_text="The type of Organization being defined.",
     )
-    founding_date = models.CharField(
-        max_length=10,
-        blank=True,
-        help_text="The founding date of the Organization in YYYY[-MM[-DD]] string format.",
-    )
-    dissolution_date = models.CharField(
-        max_length=10,
-        blank=True,
-        help_text="The dissolution date of the Organization in YYYY[-MM[-DD]] string format.",
-    )
 
     def __str__(self):
         return self.name
@@ -149,16 +134,6 @@ class Post(OCDBase):
         # if the division goes away the post is just jurisdiction-less
         on_delete=models.SET_NULL,
     )
-    start_date = models.CharField(
-        max_length=10,
-        blank=True,
-        help_text="An optional start date for the Post in YYYY[-MM[-DD]] string format.",
-    )
-    end_date = models.CharField(
-        max_length=10,
-        blank=True,
-        help_text="An optional end date for the Post in YYYY[-MM[-DD]] string format.",
-    )
     maximum_memberships = models.PositiveIntegerField(
         default=1, help_text="The maximum number of people who can hold this Post."
     )
@@ -238,11 +213,6 @@ class Person(OCDBase):
         help_text="A URL leading to an image that identifies the Person visually.",
     )
     gender = models.CharField(max_length=100, blank=True, help_text="A Person's gender")
-    summary = models.CharField(
-        max_length=500,
-        blank=True,
-        help_text="A short, one-line account of a Person's life.",
-    )
     biography = models.TextField(
         blank=True, help_text="An extended account of a Person's life."
     )
@@ -357,9 +327,6 @@ class PersonContactDetail(RelatedBase):
         blank=True,
         help_text="A short, optional note about the Contact value.",
     )
-    label = models.CharField(
-        max_length=300, blank=True, help_text="A title for the content of the Contact."
-    )
 
     person = models.ForeignKey(
         Person,
@@ -442,9 +409,6 @@ class Membership(OCDBase):
         on_delete=models.SET_NULL,
         help_text="	The Post held by the member in the Organization.",
     )
-    label = models.CharField(
-        max_length=300, blank=True, help_text="A label describing the membership."
-    )
     role = models.CharField(
         max_length=300,
         blank=True,
@@ -463,7 +427,7 @@ class Membership(OCDBase):
 
     class Meta:
         db_table = "opencivicdata_membership"
-        index_together = [["organization", "person", "label", "post"]]
+        index_together = [["organization", "person", "post"]]
 
     def __str__(self):
         return "{} in {} ({})".format(self.person, self.organization, self.role)
