@@ -162,58 +162,3 @@ def test_invalid_fields_related_item():
 
     with pytest.raises(DataImportError):
         BillImporter("jid").import_data([p1])
-
-
-@pytest.mark.django_db
-def test_locked_field():
-    create_jurisdiction()
-    bill = ScrapeBill("HB 1", "2020", "Title").as_dict()
-    bi = BillImporter("jid")
-    bi.import_data([bill])
-
-    # set classification and lock field
-    b = Bill.objects.get()
-    b.classification = ["locked"]
-    b.locked_fields = ["classification"]
-    b.save()
-
-    # reimport
-    bill = ScrapeBill("HB 1", "2020", "Title").as_dict()
-    bi = BillImporter("jid")
-    bi.import_data([bill])
-
-    b = Bill.objects.get()
-    assert b.classification == ["locked"]
-    assert b.locked_fields == ["classification"]
-
-    # do it a third time to check for the locked_fields reversion issue
-    bill = ScrapeBill("HB 1", "2020", "Title").as_dict()
-    bi = BillImporter("jid")
-    bi.import_data([bill])
-
-    b = Bill.objects.get()
-    assert b.classification == ["locked"]
-    assert b.locked_fields == ["classification"]
-
-
-@pytest.mark.django_db
-def test_locked_field_subitem():
-    create_jurisdiction()
-    bill = ScrapeBill("HB 1", "2020", "Title")
-    bill.add_source("https://example.com")
-    bi = BillImporter("jid")
-    bi.import_data([bill.as_dict()])
-
-    # lock the field
-    b = Bill.objects.get()
-    b.locked_fields = ["sources"]
-    b.save()
-
-    # reimport (without source)
-    bill = ScrapeBill("HB 1", "2020", "Title")
-    bi = BillImporter("jid")
-    bi.import_data([bill.as_dict()])
-
-    b = Bill.objects.get()
-    assert b.sources.count() == 1
-    assert b.locked_fields == ["sources"]
