@@ -27,7 +27,7 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
         *,
         chamber=None,
         from_organization=None,
-        classification=None
+        classification=None,
     ):
         super(Bill, self).__init__()
 
@@ -58,7 +58,6 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
         chamber=None,
         classification=None,
         related_entities=None,
-        extras=None
     ):
         action = Action(
             description=description,
@@ -66,7 +65,6 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
             organization_id=pseudo_organization(organization, chamber, "legislature"),
             classification=cleanup_list(classification, []),
             related_entities=[],
-            extras=extras or {},
         )
         self.actions.append(action)
         return action
@@ -89,7 +87,7 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
         primary,
         *,
         chamber=None,
-        entity_id=None
+        entity_id=None,
     ):
         sp = {
             "name": name,
@@ -116,7 +114,7 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
         *,
         scheme,
         identifier,
-        chamber=None
+        chamber=None,
     ):
         return self.add_sponsorship(
             name,
@@ -132,39 +130,35 @@ class Bill(SourceMixin, AssociatedLinkMixin, BaseModel):
     def add_subject(self, subject):
         self.subject.append(subject)
 
-    def add_abstract(self, abstract, note, date=""):
-        self.abstracts.append({"note": note, "abstract": abstract, "date": date})
+    def add_abstract(self, abstract, note):
+        self.abstracts.append({"note": note, "abstract": abstract})
 
     def add_title(self, title, note=""):
         self.other_titles.append({"note": note, "title": title})
 
-    def add_identifier(self, identifier, note="", scheme=""):
-        self.other_identifiers.append(
-            {"note": note, "identifier": identifier, "scheme": scheme}
-        )
+    def add_identifier(self, identifier):
+        self.other_identifiers.append({"identifier": identifier})
 
     def add_document_link(
-        self, note, url, *, date="", media_type="", text="", on_duplicate="warn"
+        self, note, url, *, date="", media_type="", on_duplicate="warn"
     ):
         return self._add_associated_link(
             collection="documents",
             note=note,
             url=url,
             date=date,
-            text=text,
             media_type=media_type,
             on_duplicate=on_duplicate,
         )
 
     def add_version_link(
-        self, note, url, *, date="", media_type="", text="", on_duplicate="warn"
+        self, note, url, *, date="", media_type="", on_duplicate="warn"
     ):
         return self._add_associated_link(
             collection="versions",
             note=note,
             url=url,
             date=date,
-            text=text,
             media_type=media_type,
             on_duplicate=on_duplicate,
         )
