@@ -95,16 +95,6 @@ def test_add_action():
     b.validate()
 
 
-def test_action_extra():
-    b = toy_bill()
-    b.add_action(
-        "an action with some extra information",
-        "2017-01-01",
-        extras=dict(sitting_chair="Adams"),
-    )
-    assert b.actions[0]["extras"] == {"sitting_chair": "Adams"}
-
-
 def test_add_related_bill():
     """ Make sure related bills work """
     b = toy_bill()
@@ -151,15 +141,11 @@ def test_subjects():
 
 def test_abstract():
     b = toy_bill()
-    b.add_abstract("this bill is stupid", "K-5", "1969-10-20")
-    b.add_abstract("this legislative document is ignorant", "6-12", "2010-10-10")
+    b.add_abstract("this bill is stupid", "K-5")
+    b.add_abstract("this legislative document is ignorant", "6-12")
     assert b.abstracts == [
-        {"note": "K-5", "abstract": "this bill is stupid", "date": "1969-10-20"},
-        {
-            "note": "6-12",
-            "abstract": "this legislative document is ignorant",
-            "date": "2010-10-10",
-        },
+        {"note": "K-5", "abstract": "this bill is stupid"},
+        {"note": "6-12", "abstract": "this legislative document is ignorant"},
     ]
 
 
